@@ -1,6 +1,6 @@
-from soin.base import Spider
-from soin.job import SpiderJob, JobStatus
-from soin.request import Request
 from soin import utils
+from soin.base import Spider
+from soin.job import JobStatus, SpiderJob
+from soin.request import Request
 
 __all__ = ["Spider", "SpiderJob", "JobStatus", "Request", "utils"]
