@@ -1,10 +1,11 @@
 import logging
-from pathlib import Path
 import pickle
 import signal
 import threading
 import time
+from pathlib import Path
 from typing import Dict
+
 from soin.job import JobStatus, Queue, SpiderJob
 from soin.utils import while_true
 
@@ -20,8 +21,6 @@ class Spider:
 
     def __init__(self):
         self.state_file = self.root / "spider_state.pkl"
-        self.state_save_lock = threading.Lock()
-        self.state_read_lock = threading.Lock()
         self.stop = False
         self.state = {}
         self.failed_job_dir = self.root / "failed_jobs"
@@ -52,17 +51,13 @@ class Spider:
         self.save_state()
 
     def save_state(self):
-        self.state_save_lock.acquire()
         self.state_file.write_bytes(pickle.dumps(self.state))
-        self.state_save_lock.release()
 
     def load_state(self):
-        self.state_read_lock.acquire()
         try:
             self.state = pickle.loads(self.state_file.read_bytes())
         except Exception as e:
             logging.warn(f"load state failed with {e}")
-        self.state_read_lock.release()
 
     def dispatch(self, job: SpiderJob):
         self.dispatch_queue.push(job)
@@ -89,7 +84,7 @@ class Spider:
     @while_true(1)
     def _job_result_worker(self):
         """线程中运行"""
-        job : SpiderJob = self.writeback_queue.pop()
+        job: SpiderJob = self.writeback_queue.pop()
         if job is None:
             return
         logging.info(f"get writeback job: {job}")
@@ -114,7 +109,7 @@ class Spider:
                 self.stop = True
                 logging.info(f"exceed max execution step {execute_count}, quit")
                 break
-            job : SpiderJob = self.dispatch_queue.pop()
+            job: SpiderJob = self.dispatch_queue.pop()
             if job is None:
                 continue
             logging.info(f"got job {job}")
