@@ -1,14 +1,15 @@
-from datetime import datetime, timedelta
 import enum
 import logging
 import os
 import pickle
 import typing
+from datetime import datetime, timedelta
 from uuid import uuid4
-import soin
 
 import redis
 
+import soin
+
 
 class JobStatus(enum.Enum):
     success = 0
@@ -65,21 +66,18 @@ class SpiderJob:
         self.execution_time = datetime.now() - before_execute
 
     def perform(self):
-        """运行在子节点 worker 中的逻辑
-        """
+        """运行在子节点 worker 中的逻辑"""
         raise NotImplementedError()
 
     def on_failed(self):
         raise NotImplementedError()
 
     def on_success(self):
-        """运行在主节点 worker 中的逻辑
-        """
+        """运行在主节点 worker 中的逻辑"""
         raise NotImplementedError()
 
 
 class Queue:
-
     def push(self):
         pass
 
@@ -88,7 +86,6 @@ class Queue:
 
 
 class RedisQueue(Queue):
-
     def __init__(self, queue_name, redis: redis.Redis):
         self.queue_name = queue_name
         self.redis = redis
