@@ -1,8 +1,9 @@
-from typing import Dict
-import time
-from uuid import uuid4
-import requests
 import logging
+import time
+from typing import Dict
+from uuid import uuid4
+
+import requests
 
 
 class Request:
@@ -47,9 +48,7 @@ class Request:
                 timeout=self.timeout,
             )
         except Exception as e:
-            logging.warn(
-                f"error while making request {self}, exception is {e}"
-            )
+            logging.warn(f"error while making request {self}, exception is {e}")
             return None
 
         return response
